"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = fetchFromAPI;

var _fetch = _interopRequireDefault(require("../fetch"));

var _isBrowser = _interopRequireDefault(require("../utils/isBrowser"));

/**
 * A convenience function to be used in `getInitialProps` to fetch data for the page from an
 * API endpoint at the same path as the page being requested.  So for example, when rendering
 * `/p/1`, this function will fetch data from `/api/p/1`.
 *
 * ```js
 * import fetchFromAPI from 'react-storefront/props/fetchFromAPI'
 * import createLazyProps from 'react-storefront/props/createLazyProps'
 *
 * Product.getInitialProps = createLazyProps(opts => {
 *   return fetchFromAPI(opts)
 * })
 * ```
 *
 * Or simply:
 *
 * ```js
 * Product.getInitialProps = createLazyProps(fetchFromAPI)
 * ```
 *
 * @param {Object} opts The options object provided to `getInitialProps`
 * @return {Promise} A promise that resolves to the data that the page should display
 */
function fetchFromAPI(_ref) {
  var req = _ref.req,
      asPath = _ref.asPath;
  var server = !(0, _isBrowser["default"])();
  var host = server ? req.headers['host'] : '';
  var protocol = server ? host.startsWith('localhost') ? 'http://' : 'https://' : '';
  if (asPath === '/') asPath = '';
  if (asPath.startsWith('/?')) asPath = asPath.substring(1);
  var uri = "/api".concat(asPath);

  if (server) {
    if (uri.indexOf('?') === -1) {
      uri = uri + '?_includeAppData=1';
    } else {
      uri = uri + '&_includeAppData=1';
    }
  }

  return (0, _fetch["default"])("".concat(protocol).concat(host).concat(uri)).then(function (res) {
    return res.json();
  });
}
//# sourceMappingURL=fetchFromAPI.js.map